@@ -29,6 +29,10 @@
 #include "interface.h"
 #include "asciiselect.h"
 
+#include <gconf/gconf-client.h>
+#include <gnome.h>
+
+
 void
 cb_about_click (GtkWidget *widget, gpointer user_data)
 {
@@ -41,29 +45,37 @@ cb_about_click (GtkWidget *widget, gpointer user_data)
 	    NULL
     };
     /* Translator credits */
-    gchar *translator_credits = _("");
+    gchar *translator_credits = _("translator_credits");
     GtkWidget *dialog;
-    GdkPixbuf *logo = NULL;
-    gchar *logo_fn;
+    GdkPixbuf *logo  = NULL;
+    GError    *error = NULL;
+    gchar     *logo_fn;
 
-    logo_fn = gnome_pixmap_file("gcharmap-logo.png");
-    if (logo_fn != NULL)
-    {
-	    logo = gdk_pixbuf_new_from_file(logo_fn, NULL /* error */);
-	    g_free(logo_fn);
+    logo_fn = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gnome-character-map.png", FALSE, NULL);
+    logo = gdk_pixbuf_new_from_file (logo_fn, &error);
+    
+    if (error) {
+    	    g_warning (G_STRLOC ": cannot open %s: %s", logo_fn, error->message);
+	    g_error_free (error);
     }
+    
+    g_free (logo_fn);
 
     dialog = gnome_about_new (
-      _("Gnome Character Map"),
+      _("GNOME Character Map"),
       VERSION,
       "Copyright (c) 2000 Hongli Lai",
-      _("The Gnome equalivant of Microsoft Windows' Character Map. "
+      _("The GNOME equalivant of Microsoft Windows' Character Map. "
       "Warning: might contain bad English."),
       authors,
       (const char **)documenters,
-      (const char *)translator_credits,
+      strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
       logo
     );
+    
+    if (logo) {
+    	    gdk_pixbuf_unref (logo);
+    }
     gtk_widget_show (dialog);
 }
 
@@ -78,9 +90,9 @@ void
 cb_charbtn_click (GtkButton *button, gpointer user_data)
 {
     GtkLabel *label = GTK_LABEL (GTK_BIN (button)->child);
-    gchar *text;
+    const gchar *text;
 
-    gtk_label_get (label, &text);
+    text = gtk_label_get_text (label);
 
     if (strcmp (text, _("del")) == 0) {
 	    if ( ! mainapp->insert_at_end) {
@@ -108,24 +120,30 @@ cb_charbtn_click (GtkButton *button, gpointer user_data)
 	    gint current_pos = gtk_editable_get_position(GTK_EDITABLE(mainapp->entry));
 	    gtk_editable_insert_text (GTK_EDITABLE (mainapp->entry), text,
 				      strlen (text), &current_pos);
+	    gtk_editable_set_position (GTK_EDITABLE (mainapp->entry), current_pos + 1);
     } else {
-	    gtk_entry_append_text (GTK_ENTRY (mainapp->entry), text);
+           gint current_pos;
+           gtk_editable_set_position (GTK_EDITABLE (mainapp->entry), -1);
+           current_pos = gtk_editable_get_position (GTK_EDITABLE (mainapp->entry));
+           gtk_editable_insert_text (GTK_EDITABLE (mainapp->entry), text, strlen(text), &current_pos);
+           gtk_editable_set_position (GTK_EDITABLE (mainapp->entry), current_pos + 1);
     }
 }
 
 
-void
-cb_charbtn_enter (GtkButton *button, gpointer user_data)
+gboolean
+cb_charbtn_enter (GtkButton *button, GdkEventFocus *event, gpointer user_data)
 {
     GtkLabel *label = GTK_LABEL (GTK_BIN (button)->child);
-    gchar *text, *s;
+    gchar *s;
    int code;
+    const gchar *text;
 
-    gtk_label_get (label, &text);
+    text = gtk_label_get_text (label);
     if (strcmp (text, _("del")) == 0) {
 	    code = 127;
     } else {
-	    code = (unsigned char)text[0];
+            code = g_utf8_get_char(text);
     }
 
     s = g_strdup_printf (_(" %s: Character code %d"), text, code);
@@ -134,16 +152,18 @@ cb_charbtn_enter (GtkButton *button, gpointer user_data)
     gtk_label_set_text (GTK_LABEL (mainapp->preview_label), text);
 #endif
     g_free (s);
+    return FALSE;
 }
 
 
-void
-cb_charbtn_leave (GtkButton *button, gpointer user_data)
+gboolean
+cb_charbtn_leave (GtkButton *button, GdkEventFocus *event, gpointer user_data)
 {
     gnome_appbar_pop (GNOME_APPBAR (GNOME_APP (mainapp->window)->statusbar));
 #if 0    
     gtk_label_set_text (GTK_LABEL (mainapp->preview_label), NULL);
 #endif
+    return FALSE;
 }
 
 
@@ -157,7 +177,16 @@ cb_clear_click (GtkWidget *widget, gpointer user_data)
 void
 cb_copy_click (GtkWidget *widget, gpointer user_data)
 {
-    cb_select_all_click (widget, user_data);
+    gint start, end;
+    gboolean selection_flag;
+
+    selection_flag = gtk_editable_get_selection_bounds (GTK_EDITABLE (mainapp->entry), &start, &end);
+
+    if(selection_flag)
+        gtk_editable_select_region (GTK_EDITABLE (mainapp->entry), start, end);
+    else
+        cb_select_all_click (widget, user_data);
+
     gtk_editable_copy_clipboard (GTK_EDITABLE (mainapp->entry));
     gnome_app_flash (GNOME_APP (mainapp->window), _("Text copied to clipboard..."));
 }
@@ -166,10 +195,20 @@ cb_copy_click (GtkWidget *widget, gpointer user_data)
 void
 cb_cut_click (GtkWidget *widget, gpointer user_data)
 {
-    cb_select_all_click (widget, user_data);
+    gint start, end;
+    gboolean selection_flag;
+
+    selection_flag = gtk_editable_get_selection_bounds (GTK_EDITABLE (mainapp->entry), &start, &end);
+
+    if(selection_flag)
+        gtk_editable_select_region (GTK_EDITABLE (mainapp->entry), start, end);
+    else
+        cb_select_all_click (widget, user_data);
+#if 0 /* Why the heck is this here? It makes cutting noticable slow */
     while (gtk_events_pending ()) gtk_main_iteration ();
     usleep (500000);
     while (gtk_events_pending ()) gtk_main_iteration ();
+#endif
     gtk_editable_cut_clipboard (GTK_EDITABLE (mainapp->entry));
     gnome_app_flash (GNOME_APP (mainapp->window), _("Text cut to clipboard..."));
 }
@@ -201,10 +240,8 @@ cb_fontpicker_font_set (GnomeFontPicker *gfp, gchar *font_name)
 void
 cb_help_click (GtkWidget *widget, gpointer user_data)
 {
-    gnome_help_display (
-        gnome_program_get_human_readable_name(gnome_program_get ()),
-		    "index.html",
-		    NULL /* error */);
+    GError *error = NULL;
+    gnome_help_display("gnome-character-map",NULL,&error);
 }
 
 
@@ -229,26 +266,17 @@ cb_paste_click (GtkWidget *widget, gpointer user_data)
 void
 cb_select_all_click (GtkWidget *widget, gpointer user_data)
 {
-    gtk_entry_select_region (GTK_ENTRY (mainapp->entry), 0, -1);
+    gtk_editable_select_region (GTK_EDITABLE (mainapp->entry), 0, -1);
 }
 
 
 void
 cb_set_button_focusable (GtkCheckMenuItem *checkmenuitem, gpointer user_data)
 {
-    guint i;
-
-    if (checkmenuitem->active == TRUE)
-    {
-        for (i = 0; i < g_list_length (mainapp->buttons); i++)
-            GTK_WIDGET_SET_FLAGS (GTK_WIDGET (g_list_nth_data (
-              mainapp->buttons, i)), GTK_CAN_FOCUS);
-    } else
-    {
-        for (i = 0; i < g_list_length (mainapp->buttons); i++)
-            GTK_WIDGET_UNSET_FLAGS (GTK_WIDGET (g_list_nth_data (
-              mainapp->buttons, i)), GTK_CAN_FOCUS);
-    }
+    gconf_client_set_bool(mainapp->conf, 
+			  "/apps/gcharmap/can_focus_buttons", 
+			  checkmenuitem->active, 
+			  NULL);
 }
 
 
@@ -262,37 +290,40 @@ cb_set_chartable_font (GtkWidget *widget, gpointer user_data)
 void
 cb_set_insert_at_end (GtkCheckMenuItem *checkmenuitem, gpointer user_data)
 {
-    mainapp->insert_at_end = checkmenuitem->active;
+    gconf_client_set_bool (mainapp->conf, 
+			   "/apps/gcharmap/insert_at_end", 
+			   checkmenuitem->active, 
+			   NULL);
 }
 
 
 void
 cb_toggle_actionbar (GtkCheckMenuItem *checkmenuitem, gpointer user_data)
 {
-    if (checkmenuitem->active == TRUE)
-        gtk_widget_show (mainapp->actionbar);
-    else
-        gtk_widget_hide (mainapp->actionbar);
+    gconf_client_set_bool (mainapp->conf, 
+			   "/apps/gcharmap/show_actionbar", 
+			   checkmenuitem->active, 
+			   NULL);
 }
 
 
 void
 cb_toggle_textbar (GtkCheckMenuItem *checkmenuitem, gpointer user_data)
 {
-    if (checkmenuitem->active == TRUE)
-        gtk_widget_show (mainapp->textbar);
-    else
-        gtk_widget_hide (mainapp->textbar);
+    gconf_client_set_bool (mainapp->conf, 
+			   "/apps/gcharmap/show_textbar", 
+			   checkmenuitem->active, 
+			   NULL);
 }
 
 
 void
 cb_toggle_statusbar (GtkCheckMenuItem *checkmenuitem, gpointer user_data)
 {
-    if (checkmenuitem->active == TRUE)
-        gtk_widget_show (GNOME_APP (mainapp->window)->statusbar);
-    else
-        gtk_widget_hide (GNOME_APP (mainapp->window)->statusbar);
+    gconf_client_set_bool (mainapp->conf, 
+			   "/apps/gcharmap/show_statusbar", 
+			   checkmenuitem->active, 
+			   NULL);
 }
 
 
