@@ -1,4 +1,4 @@
-/* $Id: gdict-speller.c,v 1.12 2002/03/21 03:33:47 kevinv Exp $ */
+/* $Id: gdict-speller.c,v 1.17 2002/04/26 11:50:22 gman Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -26,7 +26,6 @@
 #ifdef HAVE_GNOME_PRINT
 #  include <libgnomeprint/gnome-print.h>
 #  include <libgnomeprint/gnome-printer-dialog.h>
-#  include <libgnomeprint/gnome-printer-profile.h>
 #  include <math.h>
 #endif
 
@@ -214,6 +213,7 @@ gdict_speller_init (GDictSpeller *speller) {
                                                   _("_Look Up Word"), 100,
                                                   NULL);
 
+    gtk_dialog_set_default_response (GTK_DIALOG (speller), 100);
     g_signal_connect (G_OBJECT (speller->word_list), "row_activated",
     		      G_CALLBACK (row_activated_cb), speller);
     		      
@@ -514,11 +514,19 @@ speller_add_word (GDictSpeller *speller, gchar *word) {
 static void
 speller_set_strat_cb (GtkWidget *widget, gpointer data) {
     GDictSpeller *speller;
+    gchar *text;
     gchar *strat;
     
     speller = GDICT_SPELLER (data);
     strat = gtk_object_get_data (GTK_OBJECT (widget), "strat_name");
     speller->strat = strat;
+
+    text = gtk_editable_get_chars (GTK_EDITABLE (speller->word_entry), 0, -1);
+    gtk_editable_select_region (GTK_EDITABLE (speller->word_entry), 0,
+                                strlen (text));
+    gdict_speller_lookup (speller, text);
+    if (text)
+    	g_free (text);
 }
 
 /* speller_add_strat
@@ -629,7 +637,6 @@ spell_strat_status_cb (dict_command_t *command, DictStatusCode code,
         if ( gail_loaded )
         {
             add_atk_namedesc(ss_label, _("Search Strategy"), _("Search Strategy"));
-            add_atk_relation(ss_label, GTK_WIDGET (speller->strat_sel), ATK_RELATION_LABEL_FOR);
             add_atk_relation( GTK_WIDGET (speller->strat_sel), ss_label, ATK_RELATION_LABELLED_BY);
         }
  
