@@ -1,4 +1,4 @@
-/* Gnome Search Tool 
+/* GNOME Search Tool 
  * (C) 1998,2000 the Free Software Foundation
  *
  * Author:   George Lebl
@@ -918,7 +918,7 @@ nautilus_is_running()
 	gboolean ret;
 	
 	CORBA_exception_init (&ev); 
-	obj = bonobo_activation_activate_from_id ("OAFIID:nautilus_factory:bd1e1862-92d7-4391-963e-37583f0daef3",
+	obj = bonobo_activation_activate_from_id ("OAFIID:Nautilus_Factory",
 		Bonobo_ACTIVATION_FLAG_EXISTING_ONLY, NULL, &ev);
 		
 	ret = !CORBA_Object_is_nil (obj, &ev);
@@ -1699,6 +1699,10 @@ static void
 about_cb (GtkWidget *widget, gpointer data)
 {
 	static GtkWidget *about = NULL;
+	GdkPixbuf  	 *pixbuf;
+	GError		 *error = NULL;
+	gchar		 *file;
+	
 	static const char *authors[] = {
 		"George Lebl <jirka@5z.com>",
 		"Dennis M. Cranston <dennis_cranston@yahoo.com>",
@@ -1715,14 +1719,27 @@ about_cb (GtkWidget *widget, gpointer data)
 		return;
 	}
 
-	about = gnome_about_new(_("The Gnome Search Tool"), VERSION,
+	file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gnome-searchtool.png", FALSE, NULL);
+	pixbuf = gdk_pixbuf_new_from_file (file, &error);
+	
+	if (error) {
+		g_warning (G_STRLOC ": cannot open %s: %s", file, error->message);
+		g_error_free (error);
+	}
+	g_free (file);
+
+	about = gnome_about_new(_("GNOME Search Tool"), VERSION,
 				_("(C) 1998,2000 the Free Software Foundation"),
 				_("Frontend to the unix find/locate "
 				  "commands"),
 				authors,
 				(const char **)documenters,
 				strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
-				NULL);
+				pixbuf);
+	if (pixbuf) {
+		gdk_pixbuf_unref (pixbuf);
+	}
+										
 	g_signal_connect (G_OBJECT (about), "destroy",
 			  G_CALLBACK (gtk_widget_destroyed), &about);
 	gtk_widget_show (about);
@@ -1858,7 +1875,7 @@ static GnomeUIInfo file_menu[] = {
 };
 
 static GnomeUIInfo help_menu[] = {  
-	GNOMEUIINFO_HELP("gsearchtool"),
+	GNOMEUIINFO_HELP("gnome-search-tool"),
 	GNOMEUIINFO_MENU_ABOUT_ITEM(about_cb,NULL),
 	GNOMEUIINFO_END
 };
@@ -1882,7 +1899,7 @@ main(int argc, char *argv[])
 	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
 	textdomain(GETTEXT_PACKAGE);
 
-	gsearchtool = gnome_program_init ("gnome-search-tool", VERSION, LIBGNOMEUI_MODULE, argc, argv, NULL);
+	gsearchtool = gnome_program_init ("gnome-search-tool", VERSION, LIBGNOMEUI_MODULE, argc, argv, GNOME_PARAM_APP_DATADIR,DATADIR, NULL);
 	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-searchtool.png");
 
 	if (!bonobo_init (bonobo_activation_orb_get (), NULL, NULL))
